package com.muyu.data.source.service.impl;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.List;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.data.source.domain.AccessType;
import com.muyu.data.source.domain.req.DataSourceSaveReq;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.data.source.mapper.DataSourceMapper;
import com.muyu.data.source.domain.DataSource;
import com.muyu.data.source.service.DataSourceService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

/**
 * 数据源Service业务层处理
 *
 * @author muyu
 * @date 2024-04-21
 */
@Slf4j
@Service
public class DataSourceServiceImpl extends ServiceImpl<DataSourceMapper, DataSource>  implements DataSourceService {
    @Autowired
    private DataSourceMapper dataSourceMapper;

    /**
     * 查询数据源列表
     *
     * @param dataSource 数据源
     * @return 数据源
     */
    @Override
    public List<DataSource> list(DataSource dataSource) {
        LambdaQueryWrapper<DataSource> queryWrapper = new LambdaQueryWrapper<>();


        if (ObjUtils.notNull(dataSource.getAccessSourceName())){
            queryWrapper.like(DataSource::getAccessSourceName, dataSource.getAccessSourceName());
        }

        if (ObjUtils.notNull(dataSource.getDataSourceSystemName())){
            queryWrapper.like(DataSource::getDataSourceSystemName, dataSource.getDataSourceSystemName());
        }

        if (ObjUtils.notNull(dataSource.getHostAddress())){
            queryWrapper.eq(DataSource::getHostAddress, dataSource.getHostAddress());
        }

        if (ObjUtils.notNull(dataSource.getHostPort())){
            queryWrapper.eq(DataSource::getHostPort, dataSource.getHostPort());
        }

        if (ObjUtils.notNull(dataSource.getDataAccessTypeId())){
            queryWrapper.eq(DataSource::getDataAccessTypeId, dataSource.getDataAccessTypeId());
        }

        if (ObjUtils.notNull(dataSource.getDatabaseName())){
            queryWrapper.like(DataSource::getDatabaseName, dataSource.getDatabaseName());
        }

        if (ObjUtils.notNull(dataSource.getDataConnectionParameter())){
            queryWrapper.eq(DataSource::getDataConnectionParameter, dataSource.getDataConnectionParameter());
        }

        if (ObjUtils.notNull(dataSource.getInitialQuantity())){
            queryWrapper.eq(DataSource::getInitialQuantity, dataSource.getInitialQuantity());
        }

        if (ObjUtils.notNull(dataSource.getMaximumQuantity())){
            queryWrapper.eq(DataSource::getMaximumQuantity, dataSource.getMaximumQuantity());
        }



        if (ObjUtils.notNull(dataSource.getMaximumFrequency())){
            queryWrapper.eq(DataSource::getMaximumFrequency, dataSource.getMaximumFrequency());
        }





        return list(queryWrapper);
    }

    @Override
    public List<AccessType> findAccessType() {
        return dataSourceMapper.findAccessType();
    }

    @Override
    public Result testConnection(DataSourceSaveReq dataSourceQueryReq) {
        String user = dataSourceQueryReq.getDatabaseUserName();
        String password = dataSourceQueryReq.getDatabaseUserPassword();
        String jdbcDriver = "com.mysql.cj.jdbc.Driver";
        String url = "jdbc:mysql://"+dataSourceQueryReq.getHostAddress()+":"+dataSourceQueryReq.getHostPort()+"/"+dataSourceQueryReq.getDatabaseName();
        try {
            Connection con = DriverManager.getConnection(url, user, password);
            if (con!=null){
                return Result.success("连接成功");
            }
            Statement stmt = con.createStatement();

        } catch (SQLException e) {
            throw new RuntimeException(e);
        }

        return Result.error("连接失败");
    }
}
